@@ -56,7 +56,7 @@ import Text.XML.HaXml.Namespaces
 import Data.Maybe (fromMaybe)
 
 infixl 6 `with`, `without`
-infixr 5 `o`, `oo`, `union`, `andThen`		-- , `orelse`
+infixr 5 `o`, `oo`, `union`, `andThen`          -- , `orelse`
 infixl 5 />, </, |>|
 infixr 4 `when`, `guards`
 infixr 3 ?>, :>
@@ -77,9 +77,9 @@ type CFilter i  = Content i -> [Content i]
 -- In the algebra of combinators, @none@ is the zero, and @keep@ the identity.
 -- (They have a more general type than just CFilter.)
 keep :: a->[a]
-keep = \x->[x]
+keep x = [x]
 none :: a->[b]
-none = \x->[]
+none _ = []
 
 -- | Throw away current node, keep just the (unprocessed) children.
 children :: CFilter i
@@ -121,7 +121,7 @@ tag _ _  = []
 tagWith p x@(CElem (Elem n _ _) _) | p (printableName n)  = [x]
 tagWith _ _  = []
 
-attr n x@(CElem (Elem _ as _) _) | n `elem` (map (printableName.fst) as)  = [x]
+attr n x@(CElem (Elem _ as _) _) | n `elem` map (printableName.fst) as  = [x]
 attr _ _  = []
 
 attrval av x@(CElem (Elem _ as _) _) | av `elem` as  = [x]
@@ -144,7 +144,7 @@ find key cont c@(CElem (Elem _ as _) _) = cont (show (lookfor (N key) as)) c
 --   otherwise it applies the @yes@ filter.
 iffind :: String -> (String->CFilter i) -> CFilter i -> CFilter i
 iffind  key  yes no c@(CElem (Elem _ as _) _) =
-  case (lookup (N key) as) of
+  case lookup (N key) as of
     Nothing               -> no c
     (Just v@(AttValue _)) -> yes (show v) c
 iffind _key _yes no other = no other
@@ -184,10 +184,10 @@ f `o` g = concatMap f . g
 -- rather than one filter using the result of the other.
 --   (Has a more general type than just CFilter.)
 union :: (a->[b]) -> (a->[b]) -> (a->[b])
-union = lift (++)		-- in Haskell 98:   union = lift List.union
+union = lift (++)               -- in Haskell 98:   union = lift List.union
   where
     lift :: (a->b->d) -> (c->a) -> (c->b) -> c -> d
-    lift f g h = \x-> f (g x) (h x)
+    lift f g h x = f (g x) (h x)
 
 -- | Glue a list of filters together.  (A list version of union;
 --   also has a more general type than just CFilter.)
@@ -201,10 +201,10 @@ cat fs = foldr1 union fs
 --   works over the same data as the first, but also uses the
 --   first's result.
 andThen :: (a->c) -> (c->a->b) -> (a->b)
-andThen f g = \x-> g (f x) x			-- lift g f id
+andThen f g x = g (f x) x                    -- lift g f id
 
 -- | Process children using specified filters.
-childrenBy :: CFilter i -> CFilter i 
+childrenBy :: CFilter i -> CFilter i
 childrenBy f = f `o` children
 
 -- | Directional choice:
@@ -241,7 +241,7 @@ et f g = (f `oo` tagged elm)
 --   @path [children, tag \"name1\", attr \"attr1\", children, tag \"name2\"]@
 --   is like the XPath query @\/name1[\@attr1]\/name2@.
 path :: [CFilter i] -> CFilter i
-path fs = foldr (flip (o)) keep fs
+path fs = foldr (flip o) keep fs
 
 
 -- RECURSIVE SEARCH
@@ -264,7 +264,7 @@ when   :: CFilter i -> CFilter i -> CFilter i
 --   otherwise the content is discarded.
 guards :: CFilter i -> CFilter i -> CFilter i
 f `when` g       = g ?> f :> keep
-g `guards` f     = g ?> f :> none	-- = f `o` (keep `with` g)
+g `guards` f     = g ?> f :> none       -- = f `o` (keep `with` g)
 
 -- | Process CHildren In Place.  The filter is applied to any children
 --   of an element content, and the element rebuilt around the results.
@@ -304,7 +304,7 @@ foldXml f = f `o` chip (foldXml f)
 -- | Build an element with the given tag name - its content is the results
 --   of the given list of filters.
 mkElem :: String -> [CFilter i] -> CFilter i
-mkElem h cfs = \t-> [ CElem (Elem (N h) [] (cat cfs t)) undefined ]
+mkElem h cfs t = [ CElem (Elem (N h) [] (cat cfs t)) undefined ]
 
 -- | Build an element with the given name, attributes, and content.
 mkElemAttr :: String -> [(String,CFilter i)] -> [CFilter i] -> CFilter i
@@ -389,7 +389,7 @@ addAttribute _ _ _ = []
 -- > labelAllPaths = allPaths `o` initialise
 -- >   where
 -- >     initialise = annotateOne "/"
--- > 
+-- >
 -- >     allPaths :: CFilter a
 -- >     allPaths = inplace ( allPaths
 -- >                          `o`
@@ -463,7 +463,7 @@ tagged f = extracted name f
 attributed :: String -> CFilter i -> LabelFilter i String
 attributed key f = extracted att f
   where att (CElem (Elem _ as _) _) =
-            case (lookup (N key) as) of
+            case lookup (N key) as of
               Nothing  -> ""
               (Just v@(AttValue _)) -> show v
         att _ = ""
@@ -478,7 +478,7 @@ textlabelled f = extracted text f
 -- | Label each content with some information extracted from itself.
 extracted :: (Content i->a) -> CFilter i -> LabelFilter i a
 extracted proj f = concatMap (\c->[(proj c, c)]) . f
-                                                                                
+
 
 
 {-
