@@ -5,9 +5,9 @@
 --   streams for communication.
 
 module Text.XML.HaXml.SAX
-	( SaxElement(..)
-	, saxParse
-	) where
+        ( SaxElement(..)
+        , saxParse
+        ) where
 
 import Text.XML.HaXml.Types
 import Text.XML.HaXml.Parse
@@ -15,34 +15,34 @@ import Text.XML.HaXml.Lex
 import Text.ParserCombinators.Poly.State
 
 data SaxElement
-	= SaxDocTypeDecl DocTypeDecl
-		-- ^ A doctype declaration occured(\<!DOCTYPE\>)
-	| SaxProcessingInstruction ProcessingInstruction
-		-- ^ A processing instruction occured (\<??\>)
-	| SaxComment String		-- ^ A comment occured (\<!-- --\>)
-	| SaxElementOpen Name [Attribute] -- ^ An element was opened (\<\>)
-	| SaxElementClose Name		-- ^ An element was closed (\<\/\>)
-	| SaxElementTag Name [Attribute]
-		-- ^ An element without content occured (\<\/\>)
-	| SaxCharData CharData		-- ^ Some string data occured
-	| SaxReference Reference	-- ^ A reference occured
+        = SaxDocTypeDecl DocTypeDecl
+                -- ^ A doctype declaration occured(\<!DOCTYPE\>)
+        | SaxProcessingInstruction ProcessingInstruction
+                -- ^ A processing instruction occured (\<??\>)
+        | SaxComment String             -- ^ A comment occured (\<!-- --\>)
+        | SaxElementOpen Name [Attribute] -- ^ An element was opened (\<\>)
+        | SaxElementClose Name          -- ^ An element was closed (\<\/\>)
+        | SaxElementTag Name [Attribute]
+                -- ^ An element without content occured (\<\/\>)
+        | SaxCharData CharData          -- ^ Some string data occured
+        | SaxReference Reference        -- ^ A reference occured
 
 -- | @saxParse file content@ takes a filename and the string content of that
 --   file and generates a stream of @SaxElement@s. If an error occurs, the
 --   parsing stops and a string is returned using the @Maybe@ type.
 saxParse :: String -- ^ The filename
-	 -> String -- ^ The content of the file
-	 -> ([SaxElement],Maybe String)
-		-- ^ A tuple of the parsed elements and @Nothing@, if no
-		--   error occured, or @Just@ @String@ if an error occured.
+         -> String -- ^ The content of the file
+         -> ([SaxElement],Maybe String)
+                -- ^ A tuple of the parsed elements and @Nothing@, if no
+                --   error occured, or @Just@ @String@ if an error occured.
 saxParse file cntnt = parseStream sax emptySTs
                                     (xmlLex file cntnt)
 
 parseStream :: Parser s t a -> s -> [t] -> ([a], Maybe String)
 parseStream _ _ [] = ([],Nothing)
 parseStream p state toks = case runParser p state toks of
-	(Left err, _, _) -> ([],Just err)
-	(Right res, nstate, rest) -> (res:moreres, err)
+        (Left err, _, _) -> ([],Just err)
+        (Right res, nstate, rest) -> (res:moreres, err)
             where (moreres,err) = parseStream p nstate rest
 
 sax :: XParser SaxElement
@@ -54,40 +54,40 @@ sax = oneOf [ saxelementopen
             , saxreference
             , saxchardata
             ]
-	`adjustErr` (++("\nLooking for a SAX event:\n"
+        `adjustErr` (++("\nLooking for a SAX event:\n"
                ++"  elem-open, elem-close, PI, comment, DTD, ref, or chardata"))
 
 saxelementopen :: XParser SaxElement
 saxelementopen = do
-	tok TokAnyOpen
-	(ElemTag (N n) as) <- elemtag  -- no QN ever generated during parsing
-	(( do tok TokEndClose
-	      return (SaxElementTag n as)) `onFail`
-	 ( do tok TokAnyClose
-	      return (SaxElementOpen n as))
-	 `onFail` fail "missing > or /> in element tag")
+        tok TokAnyOpen
+        (ElemTag (N n) as) <- elemtag  -- no QN ever generated during parsing
+        ( do tok TokEndClose
+             return (SaxElementTag n as)) `onFail`
+          ( do tok TokAnyClose
+               return (SaxElementOpen n as))
+          `onFail` fail "missing > or /> in element tag"
 
 saxelementclose :: XParser SaxElement
 saxelementclose = do
-	tok TokEndOpen
-	n <- name
-	tok TokAnyClose
-	return (SaxElementClose n)
+        tok TokEndOpen
+        n <- name
+        tok TokAnyClose
+        return (SaxElementClose n)
 
 saxcomment :: XParser SaxElement
-saxcomment = comment >>= return . SaxComment
+saxcomment = SaxComment <$> comment
 
 saxchardata :: XParser SaxElement
 saxchardata =
-  (cdsect >>= return . SaxCharData)
+  (SaxCharData <$>cdsect)
   `onFail`
-  (chardata >>= return . SaxCharData)
+  (SaxCharData <$>chardata)
 
 saxreference :: XParser SaxElement
-saxreference = reference >>= return . SaxReference
+saxreference = SaxReference <$> reference
 
 saxdoctypedecl :: XParser SaxElement
-saxdoctypedecl = doctypedecl >>= return . SaxDocTypeDecl
+saxdoctypedecl = SaxDocTypeDecl <$> doctypedecl
 
 saxprocessinginstruction :: XParser SaxElement
 saxprocessinginstruction = fmap SaxProcessingInstruction processinginstruction
