@@ -15,10 +15,8 @@ import Control.Monad
 import Control.Exception as E
 import System.Directory
 import Data.List
-import Data.Maybe (fromMaybe,catMaybes)
+import Data.Maybe (fromMaybe,mapMaybe)
 import Data.Function (on)
-import Data.Monoid (mconcat)
---import Either
 
 import Text.XML.HaXml            (version)
 import Text.XML.HaXml.Types
@@ -37,7 +35,7 @@ import Text.XML.HaXml.Schema.PrettyHaskell
 import qualified Text.XML.HaXml.Schema.PrettyHsBoot     as HsBoot
 import qualified Text.XML.HaXml.Schema.HaskellTypeModel as Haskell
 import Text.ParserCombinators.Poly
-import Text.PrettyPrint.HughesPJ (render,vcat)
+import Text.PrettyPrint.HughesPJ (render)
 
 fst3 :: (a,b,c) -> a
 fst3 (a,_,_) = a
@@ -48,12 +46,12 @@ argDirsToFiles = do
   args <- getArgs
   when ("--version" `elem` args) $ do
       putStrLn $ "part of HaXml-"++version
-      exitWith ExitSuccess
+      exitSuccess
   when ("--help" `elem` args) $ do
-      putStrLn $ "Usage: FpMLToHaskell xsdDir haskellDir"
-      putStrLn $ "    -- The results go into haskelldir/Data/FpML/file0.hs etc"
-      putStrLn $ "See http://haskell.org/HaXml"
-      exitWith ExitSuccess
+      putStrLn "Usage: FpMLToHaskell xsdDir haskellDir"
+      putStrLn "    -- The results go into haskelldir/Data/FpML/file0.hs etc"
+      putStrLn "See http://haskell.org/HaXml"
+      exitSuccess
   case args of
     [xsddir,hdir]-> do
             files <- fmap (filter (".xsd" `isSuffixOf`))
@@ -61,21 +59,21 @@ argDirsToFiles = do
             let newdirs = map (\file->hdir++"/"++dirOf (fpml file)) files
             mapM_ (\newdir -> do createDirectoryIfMissing True newdir) newdirs
             return (xsddir
-                   ,map (\f-> (f, hdir++"/"++(reslash (fpml f))++".hs")) files)
+                   ,map (\f-> (f, hdir++"/"++reslash (fpml f)++".hs")) files)
     _ -> do prog <- getProgName
             putStrLn ("Usage: "++prog++" xsdDir haskellDir")
             exitFailure
  where
   reslash = map (\c-> case c of '.'->'/'; _->c)
-  dirOf   = concat . intersperse "/" . init . wordsBy '.'
-  wordsBy c s = let (a,b) = span (/=c) s in
-                if null b then [a] else a: wordsBy c (tail b)
+  dirOf   = intercalate "/" . init . wordsBy' '.'
+  wordsBy' c s = let (a,b) = span (/=c) s in
+                if null b then [a] else a: wordsBy' c (tail b)
 
 main ::IO ()
 main = do
     (dir,files) <- argDirsToFiles
-    deps <- flip mapM files (\ (inf,outf)-> do
-        hPutStrLn stdout $ "Reading "++inf
+    deps <- forM files (\ (inf,_outf)-> do
+        putStrLn $ "Reading "++inf
         thiscontent <- readFileUTF8 (dir++"/"++inf)
         let d@Document{} = resolveAllNames qualify
                            . either (error . ("not XML:\n"++)) id
@@ -85,11 +83,11 @@ main = do
             (Left msg,_) -> do hPutStrLn stderr msg
                                return ([], undefined)
             (Right v,[]) ->    return (Env.gatherImports v, v)
-            (Right v,_)  -> do hPutStrLn stdout $ "Parse incomplete!"
-                               hPutStrLn stdout $ inf
-                               hPutStrLn stdout $ "\n-----------------\n"
-                               hPutStrLn stdout $ show v
-                               hPutStrLn stdout $ "\n-----------------\n"
+            (Right v,_)  -> do putStrLn "Parse incomplete!"
+                               putStrLn inf
+                               putStrLn "\n-----------------\n"
+                               putStrLn $ show v
+                               putStrLn "\n-----------------\n"
                                return ([],v)
         )
     let filedeps :: [[((FilePath,FilePath),([(FilePath,Maybe String)],Schema))]]
@@ -99,9 +97,9 @@ main = do
                             (zip files deps)
         -- a single supertype environment, closed over all modules
         supertypeEnv :: Environment
-        supertypeEnv = foldr (\fs e->
-                              foldr (\((inf,_),(_,v))-> mkEnvironment inf v)
-                                    e fs)
+        supertypeEnv = foldr (flip (foldr
+                                    (\ ((inf, _), (_, v)) ->
+                                       mkEnvironment inf v)))
                              emptyEnv filedeps
         adjust :: Environment -> Environment
         adjust env = env{ env_extendty = env_extendty supertypeEnv
@@ -137,15 +135,13 @@ main = do
                                                (\d-> fst3 $
                                                      fromMaybe (error "FME") $
                                                      lookup d environs)
-                            in flip map cyclic
-                                    (\((inf,outf),(_,v))->
-                                      (inf,(adjust $ mkEnvironment inf v
-                                                   $ jointEnv
-                                           ,outf
-                                           ,v)
-                                      )
-                                    )
-    flip mapM_ environs (\ (inf,(env,outf,v))-> do
+                            in flip map cyclic $
+                               \((inf,outf),(_,v))->
+                                 (inf,(adjust $ mkEnvironment inf v jointEnv
+                                      ,outf
+                                      ,v)
+                                 )
+    forM_ environs (\ (inf,(env,outf,v))-> do
         o  <- openFile outf WriteMode
         hb <- openFile (bootf outf) WriteMode
         hSetEncoding o  utf8
@@ -154,9 +150,9 @@ main = do
             haskell = Haskell.mkModule inf v decls
             doc     = ppModule fpmlNameConverter haskell
             docboot = HsBoot.ppModule fpmlNameConverter haskell
-        hPutStrLn stdout $ "Writing "++outf
+        putStrLn $ "Writing "++outf
         hPutStrLn o $ render doc
-        hPutStrLn stdout $ "Writing "++(bootf outf)
+        putStrLn $ "Writing "++bootf outf
         hPutStrLn hb $ render docboot
         hFlush o
         hFlush hb
@@ -171,36 +167,36 @@ bootf x = case reverse x of
 -- | Calculate dependency ordering of modules, least dependent first.
 --   Cyclic groups may occur, suitably placed in the ordering.
 ordered :: (Eq a, Eq b) => (b->a) -> (b->[a]) -> (a->Maybe b) -> [b] -> [[b]]
-ordered name deps env list =
-    let cycles    = cyclicDeps name deps env list
+ordered name' deps env list =
+    let cycles    = cyclicDeps name' deps env list
         noncyclic = map (:[]) $ list \\ concat cycles
         workqueue = noncyclic++cycles
-    in traverse [] workqueue
+    in traverse' [] workqueue
   where
-    traverse acc []     = acc
-    traverse acc (w:wq) = if all (`elem` concatMap (map name) acc)
-                                 (concatMap deps w \\ map name w)
-                          then traverse (acc++[w]) wq
-                          else traverse     acc   (wq++[w])
+    traverse' acc []     = acc
+    traverse' acc (w:wq) = if all (`elem` concatMap (map name') acc)
+                                 (concatMap deps w \\ map name' w)
+                          then traverse' (acc++[w]) wq
+                          else traverse'     acc   (wq++[w])
 
 -- | Find cyclic dependencies between modules.
 cyclicDeps :: Eq a => (b->a) -> (b->[a]) -> (a->Maybe b) -> [b] -> [[b]]
-cyclicDeps name deps env = nubBy (setEq`on`map name)
+cyclicDeps name' deps env = nubBy (setEq`on`map name')
                            . (\cs-> foldl minimal cs cs)
                            . concatMap (walk [])
   where
 --  walk :: [b] -> b -> [[b]]
-    walk acc t = if name t `elem` map name acc then [acc]
-                 else concatMap (walk (t:acc)) (catMaybes . map env $ deps t)
+    walk acc t = if name' t `elem` map name' acc then [acc]
+                 else concatMap (walk (t:acc)) (mapMaybe env $ deps t)
     minimal acc c = concatMap (prune c) acc
-    prune c c' = if map name c `isProperSubsetOf` map name c' then [] else [c']
+    prune c c' = [c' | not (map name' c `isProperSubsetOf` map name' c')]
     isSubsetOf a b = all (`elem`b) a
     setEq a b            = a`isSubsetOf`b &&      b`isSubsetOf`a
     isProperSubsetOf a b = a`isSubsetOf`b && not (b`isSubsetOf`a)
 
 -- | A variation on the standard lookup function.
 lookupWith :: Eq a => (b->a) -> a -> [b] -> Maybe b
-lookupWith proj x [] = Nothing
+lookupWith _ _ [] = Nothing
 lookupWith proj x (y:ys) | proj y == x = Just y
                          | otherwise   = lookupWith proj x ys
 
@@ -208,9 +204,8 @@ lookupWith proj x (y:ys) | proj y == x = Just y
 targetNamespace :: Element i -> String
 targetNamespace (Elem qn attrs _) =
     if qn /= xsdSchema then "ERROR! top element not an xsd:schema tag"
-    else case lookup (N "targetNamespace") attrs of
-           Nothing -> "ERROR! no targetNamespace specified"
-           Just atv -> show atv
+    else maybe "ERROR! no targetNamespace specified" show
+         (lookup (N "targetNamespace") attrs)
 
 -- | The XSD Namespace.
 xsdSchema :: QName
@@ -222,4 +217,4 @@ readFileUTF8 :: FilePath -> IO String
 readFileUTF8 file = do
     h <- openFile file ReadMode
     (do hSetEncoding h utf8
-        hGetContents h) `E.onException` (hClose h)
+        hGetContents h) `E.onException` hClose h
